@@ -1,11 +1,7 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function
-
 from ._core.accumulators import Mean, Sum, WeightedMean, WeightedSum
+from ._internal.typing import Accumulator
 
-del absolute_import, division, print_function
-
-__all__ = ("Sum", "Mean", "WeightedSum", "WeightedMean")
+__all__ = ("Sum", "Mean", "WeightedSum", "WeightedMean", "Accumulator")
 
 for cls in (Sum, Mean, WeightedSum, WeightedMean):
     cls.__module__ = "boost_histogram.accumulators"
